/*------------------------------------------------------------------------------
  28.0 - Site Icon
------------------------------------------------------------------------------*/

.site-icon-preview .favicon-preview {
	margin: 5px 0 20px;
	overflow: hidden;
	position: relative;
	max-width: 180px;
}

.site-icon-preview .favicon,
.site-icon-preview .browser-title {
	height: 16px;
	left: 88px;
	overflow: hidden;
	position: absolute;
	top: 16px;
}

.site-icon-preview .favicon {
	width: 16px;
}

.site-icon-preview .browser-title {
	left: 109px;
	width: 72px;
	white-space: nowrap;
}

.site-icon-preview .app-icon-preview {
	background-color: #000;
	border-radius: 16px;
	height: 64px;
	overflow: hidden;
	width: 64px;
	margin-top: 5px;
}

/* rtl:ignore */
.site-icon-preview .favicon,
.site-icon-preview .app-icon-preview {
	direction: ltr;
}

.customize-control-site_icon .favicon-preview {
	float: left;
	margin-right: 12px;
	margin-bottom: 0;
}

.customize-control-site_icon .app-icon-preview {
	margin-top: 9px;
}

.site-icon-section button.reset {
	color: #b32d2e;
	text-decoration: none;
	border-color: transparent;
	box-shadow: none;
	background: transparent;
}

.site-icon-section button.reset:focus,
.site-icon-section button.reset:hover {
	background: #b32d2e;
	color: #fff;
	border-color: #b32d2e;
	box-shadow: 0 0 0 1px #b32d2e;
}

.site-icon-section .action-buttons {
	display: flex;
	flex-wrap: wrap;
	gap: 10px;
}
