$scheme-name: "modern";
$base-color: #1e1e1e;
$highlight-color: #3858e9;
$menu-submenu-focus-text: #33f078;
$notification-color: $highlight-color;

$link: $highlight-color;
$link-focus: darken($highlight-color, 10%);

$custom-welcome-panel: "false";

@import "../_admin.scss";
